==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Uncertainty/Algorithm/Analytical/SORM/SORM.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  SORM.cxx
 *  @brief SORM implements the Second Order Reliability Method
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-09-13 22:37:56 +0200 (sam 13 sep 2008) $
 *  Id:      $Id: SORM.cxx 929 2008-09-13 20:37:56Z dutka $
 */

#include "SORM.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      CLASSNAMEINIT(SORM);

      /*
       * @brief  Standard constructor: the class is defined by an optimisation algorithm, a failure event and a physical starting point
       */
      SORM::SORM(const NearestPointAlgorithm & nearestPointAlgorithm,
		 const Event & event,
		 const NumericalPoint & physicalStartingPoint):
	Analytical(nearestPointAlgorithm, event, physicalStartingPoint),
	result_()
      {
	// Nothing to do
      }

      /* Virtual constructor */
      SORM * SORM::clone() const
      {
	return new SORM(*this);
      }

      /* Result accessor */
      SORMResult SORM::getResult() const
      {
	return result_;
      }

      /* Result accessor */
      void SORM::setResult(const SORMResult & result)
      {
	result_ = result;
      }

      /* String converter */ 
      String SORM::str() const
      {   
	OSS oss;
	oss << "class=" << SORM::GetClassName()
            << " " << Analytical::str()
            << " result=" << result_;
	return oss;
      }

      /* Function that computes the design point by re-using the Analytical::run() and creates a SORMResult */
      void SORM::run()
      {
	Analytical::run();
	result_ = SORMResult(Analytical::getAnalyticalResult().getStandardSpaceDesignPoint(), Analytical::getAnalyticalResult().getLimitStateVariable(), Analytical::getAnalyticalResult().getIsStandardPointOriginInFailureSpace());
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/src/Uncertainty/Algorithm/Analytical/SORM/SORM.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  SORM.cxx
 *  @brief SORM implements the Second Order Reliability Method
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: SORM.cxx 1262 2009-05-28 12:47:53Z dutka $
 */

#include "SORM.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      CLASSNAMEINIT(SORM);

      /*
       * @brief  Standard constructor: the class is defined by an optimisation algorithm, a failure event and a physical starting point
       */
      SORM::SORM(const NearestPointAlgorithm & nearestPointAlgorithm,
		 const Event & event,
		 const NumericalPoint & physicalStartingPoint):
	Analytical(nearestPointAlgorithm, event, physicalStartingPoint),
	result_()
      {
	// Nothing to do
      }

      /* Virtual constructor */
      SORM * SORM::clone() const
      {
	return new SORM(*this);
      }

      /* Result accessor */
      SORMResult SORM::getResult() const
      {
	return result_;
      }

      /* Result accessor */
      void SORM::setResult(const SORMResult & result)
      {
	result_ = result;
      }

      /* String converter */ 
      String SORM::__repr__() const
      {   
	OSS oss;
	oss << "class=" << SORM::GetClassName()
            << " " << Analytical::__repr__()
            << " result=" << result_;
	return oss;
      }

      /* Function that computes the design point by re-using the Analytical::run() and creates a SORMResult */
      void SORM::run()
      {
	Analytical::run();
	result_ = SORMResult(Analytical::getAnalyticalResult().getStandardSpaceDesignPoint(), Analytical::getAnalyticalResult().getLimitStateVariable(), Analytical::getAnalyticalResult().getIsStandardPointOriginInFailureSpace());
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
